# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Types.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Types.proto',
  package='protocol',
  syntax='proto3',
  serialized_pb=_b('\n\x0bTypes.proto\x12\x08protocol\"\'\n\x12MultihashReference\x12\x11\n\treference\x18\x01 \x01(\t\"\x0f\n\rNullReference\"t\n\x0e\x43hainReference\x12-\n\x05\x63hain\x18\x01 \x01(\x0b\x32\x1c.protocol.MultihashReferenceH\x00\x12&\n\x03nil\x18\x02 \x01(\x0b\x32\x17.protocol.NullReferenceH\x00\x42\x0b\n\treferenceB\x1e\n\x1cio.mediachain.protocol.typesb\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_MULTIHASHREFERENCE = _descriptor.Descriptor(
  name='MultihashReference',
  full_name='protocol.MultihashReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='protocol.MultihashReference.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=64,
)


_NULLREFERENCE = _descriptor.Descriptor(
  name='NullReference',
  full_name='protocol.NullReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=81,
)


_CHAINREFERENCE = _descriptor.Descriptor(
  name='ChainReference',
  full_name='protocol.ChainReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain', full_name='protocol.ChainReference.chain', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nil', full_name='protocol.ChainReference.nil', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='reference', full_name='protocol.ChainReference.reference',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=83,
  serialized_end=199,
)

_CHAINREFERENCE.fields_by_name['chain'].message_type = _MULTIHASHREFERENCE
_CHAINREFERENCE.fields_by_name['nil'].message_type = _NULLREFERENCE
_CHAINREFERENCE.oneofs_by_name['reference'].fields.append(
  _CHAINREFERENCE.fields_by_name['chain'])
_CHAINREFERENCE.fields_by_name['chain'].containing_oneof = _CHAINREFERENCE.oneofs_by_name['reference']
_CHAINREFERENCE.oneofs_by_name['reference'].fields.append(
  _CHAINREFERENCE.fields_by_name['nil'])
_CHAINREFERENCE.fields_by_name['nil'].containing_oneof = _CHAINREFERENCE.oneofs_by_name['reference']
DESCRIPTOR.message_types_by_name['MultihashReference'] = _MULTIHASHREFERENCE
DESCRIPTOR.message_types_by_name['NullReference'] = _NULLREFERENCE
DESCRIPTOR.message_types_by_name['ChainReference'] = _CHAINREFERENCE

MultihashReference = _reflection.GeneratedProtocolMessageType('MultihashReference', (_message.Message,), dict(
  DESCRIPTOR = _MULTIHASHREFERENCE,
  __module__ = 'Types_pb2'
  # @@protoc_insertion_point(class_scope:protocol.MultihashReference)
  ))
_sym_db.RegisterMessage(MultihashReference)

NullReference = _reflection.GeneratedProtocolMessageType('NullReference', (_message.Message,), dict(
  DESCRIPTOR = _NULLREFERENCE,
  __module__ = 'Types_pb2'
  # @@protoc_insertion_point(class_scope:protocol.NullReference)
  ))
_sym_db.RegisterMessage(NullReference)

ChainReference = _reflection.GeneratedProtocolMessageType('ChainReference', (_message.Message,), dict(
  DESCRIPTOR = _CHAINREFERENCE,
  __module__ = 'Types_pb2'
  # @@protoc_insertion_point(class_scope:protocol.ChainReference)
  ))
_sym_db.RegisterMessage(ChainReference)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\034io.mediachain.protocol.types'))
import grpc
from grpc.beta import implementations as beta_implementations
from grpc.beta import interfaces as beta_interfaces
from grpc.framework.common import cardinality
from grpc.framework.interfaces.face import utilities as face_utilities
# @@protoc_insertion_point(module_scope)
